@@ -1,7 +1,7 @@
 /* -*- buffer-read-only: t -*- vi: set ro:
  *
  * Prototypes for agen5
- * Generated Sun Mar 31 10:41:50 PDT 2013
+ * Generated Sun Sep  8 10:51:09 PDT 2013
  */
 #ifndef AGEN5_PROTO_H_GUARD
 #define AGEN5_PROTO_H_GUARD 1
@@ -163,6 +163,9 @@ load_file(char const * fname);
 /*
  *  Extracted from expGuile.c
  */
+static char *
+ag_scm2zchars(SCM s, const char * type);
+
 static teGuileType
 ag_scm_type_e(SCM typ);
 
@@ -236,24 +239,6 @@ do_suffix(char const * const text, char const * fname, int lineNo);
 static char const *
 load_pseudo_mac(char const * text, char const * fname);
 
-/*
- *  Extracted from scmStrings.c
- */
-static void
-ag_scribble_init(void);
-
-static void
-ag_scribble_deinit(void);
-
-static void
-ag_scribble_free(void);
-
-static char *
-ag_scribble(ssize_t size);
-
-static char *
-ag_scm2zchars(SCM s, const char * type);
-
 /*
  *  Extracted from tpLoad.c
  */
